@@ -1,7 +1,7 @@
 /*
  *  editdlg.cpp  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include "editdlg_p.h"
 #include "editdlgtypes.h"
 
-#include "alarmcalendar.h"
 #include "alarmtimewidget.h"
 #include "deferdlg.h"
 #include "functions.h"
@@ -32,6 +31,7 @@
 #include "preferences.h"
 #include "recurrenceedit.h"
 #include "reminder.h"
+#include "resourcescalendar.h"
 #include "resources/datamodel.h"
 #include "resources/resources.h"
 #include "lib/autoqpointer.h"
@@ -50,8 +50,6 @@
 #include "lib/timespinbox.h"
 #include "kalarm_debug.h"
 
-#include <Libkdepim/MaillistDrag>
-
 #include <KLocalizedString>
 #include <KConfig>
 #include <KSharedConfig>
@@ -235,7 +233,6 @@ void EditAlarmDlg::init(const KAEvent* event)
         QHBoxLayout* box = new QHBoxLayout();
         frame->setLayout(box);
         box->setContentsMargins(0, 0, 0, 0);
-        box->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         QLabel* label = new QLabel(i18nc("@label:textbox", "Template name:"));
         label->setFixedSize(label->sizeHint());
         box->addWidget(label);
@@ -259,9 +256,6 @@ void EditAlarmDlg::init(const KAEvent* event)
     mainScroll->setWidget(mainPage);   // mainPage becomes the child of mainScroll
     connect(mainPage, &PageFrame::shown, this, &EditAlarmDlg::slotShowMainPage);
     QVBoxLayout* topLayout = new QVBoxLayout(mainPage);
-    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    topLayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Recurrence tab
     StackedScrollWidget* recurScroll = new StackedScrollWidget(mTabScrollGroup);
@@ -269,7 +263,6 @@ void EditAlarmDlg::init(const KAEvent* event)
     mRecurPageIndex = 1;
     QFrame* recurTab = new QFrame;
     QVBoxLayout* recurTabLayout = new QVBoxLayout();
-    recurTabLayout->setContentsMargins(dcm, dcm, dcm, dcm);
     recurTab->setLayout(recurTabLayout);
     recurScroll->setWidget(recurTab);   // recurTab becomes the child of recurScroll
     mRecurrenceEdit = new RecurrenceEdit(mReadOnly);
@@ -284,8 +277,6 @@ void EditAlarmDlg::init(const KAEvent* event)
     QGroupBox* actionBox = new QGroupBox(i18nc("@title:group", "Action"), mainPage);
     topLayout->addWidget(actionBox, 1);
     QVBoxLayout* layout = new QVBoxLayout(actionBox);
-    layout->setContentsMargins(dcm, dcm, dcm, dcm);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     type_init(actionBox, layout);
 
@@ -295,8 +286,6 @@ void EditAlarmDlg::init(const KAEvent* event)
         mDeferGroup = new QGroupBox(i18nc("@title:group", "Deferred Alarm"), mainPage);
         topLayout->addWidget(mDeferGroup);
         QHBoxLayout* hlayout = new QHBoxLayout(mDeferGroup);
-        hlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-        hlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         QLabel* label = new QLabel(i18nc("@label", "Deferred to:"), mDeferGroup);
         label->setFixedSize(label->sizeHint());
         hlayout->addWidget(label);
@@ -321,8 +310,6 @@ void EditAlarmDlg::init(const KAEvent* event)
         QGroupBox* templateTimeBox = new QGroupBox(i18nc("@title:group", "Time"), mainPage);
         topLayout->addWidget(templateTimeBox);
         QGridLayout* grid = new QGridLayout(templateTimeBox);
-        grid->setContentsMargins(dcm, dcm, dcm, dcm);
-        grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         mTemplateTimeGroup = new ButtonGroup(templateTimeBox);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::slotTemplateTimeType);
         connect(mTemplateTimeGroup, &ButtonGroup::buttonSet, this, &EditAlarmDlg::contentsChanged);
@@ -338,7 +325,6 @@ void EditAlarmDlg::init(const KAEvent* event)
         QWidget* box = new QWidget(templateTimeBox);
         QHBoxLayout* layout = new QHBoxLayout(box);
         layout->setContentsMargins(0, 0, 0, 0);
-        layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         mTemplateUseTime = new RadioButton(i18nc("@option:radio", "Time:"), box);
         mTemplateUseTime->setFixedSize(mTemplateUseTime->sizeHint());
         mTemplateUseTime->setReadOnly(mReadOnly);
@@ -366,7 +352,6 @@ void EditAlarmDlg::init(const KAEvent* event)
         box = new QWidget(templateTimeBox);
         layout = new QHBoxLayout(box);
         layout->setContentsMargins(0, 0, 0, 0);
-        layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
         mTemplateUseTimeAfter = new RadioButton(i18nc("@option:radio", "Time from now:"), box);
         mTemplateUseTimeAfter->setFixedSize(mTemplateUseTimeAfter->sizeHint());
         mTemplateUseTimeAfter->setReadOnly(mReadOnly);
@@ -402,7 +387,6 @@ void EditAlarmDlg::init(const KAEvent* event)
     topLayout->addWidget(mMoreOptions);
     QVBoxLayout* moreLayout = new QVBoxLayout(mMoreOptions);
     moreLayout->setContentsMargins(0, 0, 0, 0);
-    moreLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Reminder
     mReminder = createReminder(mMoreOptions);
@@ -421,7 +405,8 @@ void EditAlarmDlg::init(const KAEvent* event)
     moreLayout->addWidget(mLateCancel, 0, Qt::AlignLeft);
 
     PackedLayout* playout = new PackedLayout(Qt::AlignJustify);
-    playout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    playout->setHorizontalSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
+    playout->setVerticalSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     moreLayout->addLayout(playout);
 
     // Acknowledgement confirmation required - default = no confirmation
@@ -604,7 +589,7 @@ void EditAlarmDlg::initValues(const KAEvent* event)
     if (!deferGroupVisible  &&  mDeferGroup)
         mDeferGroup->hide();
 
-    bool empty = AlarmCalendar::resources()->events(CalEvent::TEMPLATE).isEmpty();
+    bool empty = ResourcesCalendar::instance()->events(CalEvent::TEMPLATE).isEmpty();
     if (mLoadTemplateButton)
         mLoadTemplateButton->setEnabled(!empty);
 }
@@ -860,7 +845,7 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
     if (!mDeferGroupHeight)
     {
         if (mDeferGroup)
-            mDeferGroupHeight = mDeferGroup->height() + style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+            mDeferGroupHeight = mDeferGroup->height() + style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing);
         QSize s;
         if (Config::readWindowSize(mTemplate ? TEMPLATE_DIALOG_NAME : EDIT_DIALOG_NAME, s))
         {
@@ -1006,7 +991,7 @@ bool EditAlarmDlg::validate()
             errmsg = i18nc("@info", "You must enter a name for the alarm template");
         else if (name != mSavedTemplateName)
         {
-            if (AlarmCalendar::resources()->templateEvent(name))
+            if (ResourcesCalendar::instance()->templateEvent(name))
                 errmsg = i18nc("@info", "Template name is already in use");
         }
         if (!errmsg.isEmpty())
