@@ -20,7 +20,6 @@
 
 #include "mainwindow.h"
 
-#include "alarmcalendar.h"
 #include "alarmlistdelegate.h"
 #include "alarmlistview.h"
 #include "birthdaydlg.h"
@@ -30,6 +29,7 @@
 #include "newalarmaction.h"
 #include "prefdlg.h"
 #include "preferences.h"
+#include "resourcescalendar.h"
 #include "resourceselector.h"
 #include "templatedlg.h"
 #include "templatemenuaction.h"
@@ -40,6 +40,7 @@
 #include "resources/resources.h"
 #include "resources/eventmodel.h"
 #include "lib/autoqpointer.h"
+#include "lib/dragdrop.h"
 #include "lib/messagebox.h"
 #include "lib/synchtimer.h"
 #include "kalarm_debug.h"
@@ -47,12 +48,7 @@
 #include <KAlarmCal/AlarmText>
 #include <KAlarmCal/KAEvent>
 
-#include <Libkdepim/MaillistDrag>
-#include <KMime/Message>
 #include <AkonadiCore/Item>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiWidgets/ControlGui>
 #include <KCalendarCore/MemoryCalendar>
 #include <KCalUtils/ICalDrag>
 using namespace KCalendarCore;
@@ -85,9 +81,9 @@ using namespace KCalUtils;
 #include <QMimeDatabase>
 #include <QInputDialog>
 #include <QUrl>
-#include <QUrlQuery>
 #include <QMenuBar>
 #include <QSystemTrayIcon>
+#include <QMimeData>
 
 using namespace KAlarmCal;
 
@@ -155,7 +151,7 @@ MainWindow::MainWindow(bool restored)
     setCentralWidget(mSplitter);
 
     // Create the calendar resource selector widget
-    Akonadi::ControlGui::widgetNeedsAkonadi(this);
+    DataModel::widgetNeedsDatabase(this);
     mResourceSelector = new ResourceSelector(mSplitter);
     mSplitter->setStretchFactor(0, 0);   // don't resize resource selector when window is resized
     mSplitter->setStretchFactor(1, 1);
@@ -754,8 +750,15 @@ void MainWindow::slotDelete(bool force)
     else
     {
         // Delete the events from the calendar and displays
-        KAlarm::deleteEvents(events, true, this);
-        Undo::saveDeletes(undos);
+        Resource resource;
+        const KAlarm::UpdateResult status = KAlarm::deleteEvents(events, resource, true, this);
+        if (status.status < KAlarm::UPDATE_FAILED)
+        {
+            // Create the undo list
+            for (int i = status.failed.count();  --i >= 0; )
+                undos.removeAt(status.failed.at(i));
+            Undo::saveDeletes(undos);
+        }
     }
 }
 
@@ -769,17 +772,20 @@ void MainWindow::slotReactivate()
     mListView->clearSelection();
 
     // Add the alarms to the displayed lists and to the calendar file
-    Undo::EventList undos;
-    QVector<EventId> ineligibleIDs;
-    KAlarm::reactivateEvents(events, ineligibleIDs, nullptr, this);
-
-    // Create the undo list, excluding ineligible events
-    for (int i = 0, end = events.count();  i < end;  ++i)
+    Resource resource;   // active alarms resource which alarms are restored to
+    QVector<int> ineligibleIndexes;
+    const KAlarm::UpdateResult status = KAlarm::reactivateEvents(events, ineligibleIndexes, resource, this);
+    if (status.status < KAlarm::UPDATE_FAILED)
     {
-        if (!ineligibleIDs.contains(EventId(events[i])))
-            undos.append(events[i], Resources::resourceForEvent(events[i].id()));
+        // Create the undo list, excluding ineligible events
+        Undo::EventList undos;
+        for (int i = 0, end = events.count();  i < end;  ++i)
+        {
+            if (!ineligibleIndexes.contains(i)  &&  !status.failed.contains(i))
+                undos.append(events[i], resource);
+        }
+        Undo::saveReactivates(undos);
     }
-    Undo::saveReactivates(undos);
 }
 
 /******************************************************************************
@@ -846,7 +852,8 @@ void MainWindow::slotWakeFromSuspend()
 */
 void MainWindow::slotImportAlarms()
 {
-    AlarmCalendar::resources()->importAlarms(this);
+    Resource resource;
+    KAlarm::importAlarms(resource, this);
 }
 
 /******************************************************************************
@@ -858,8 +865,8 @@ void MainWindow::slotExportAlarms()
     QVector<KAEvent> events = mListView->selectedEvents();
     if (!events.isEmpty())
     {
-        KAEvent::List evts = KAEvent::ptrList(events);
-        AlarmCalendar::exportAlarms(evts, this);
+        const KAEvent::List evts = KAEvent::ptrList(events);
+        KAlarm::exportAlarms(evts, this);
     }
 }
 
@@ -880,15 +887,19 @@ void MainWindow::slotBirthdays()
         {
             mListView->clearSelection();
             // Add alarm to the displayed lists and to the calendar file
-            KAlarm::UpdateResult status = KAlarm::addEvents(events, dlg, true, true);
+            Resource resource;
+            const KAlarm::UpdateResult status = KAlarm::addEvents(events, resource, dlg, true, true);
+            if (status.status < KAlarm::UPDATE_FAILED)
+            {
+                // Create the undo list
+                Undo::EventList undos;
+                for (int i = 0, end = events.count();  i < end;  ++i)
+                    if (!status.failed.contains(i))
+                        undos.append(events[i], resource);
+                Undo::saveAdds(undos, i18nc("@info", "Import birthdays"));
 
-            Undo::EventList undos;
-            for (int i = 0, end = events.count();  i < end;  ++i)
-                undos.append(events[i], Resources::resourceForEvent(events[i].id()));
-            Undo::saveAdds(undos, i18nc("@info", "Import birthdays"));
-
-            if (status != KAlarm::UPDATE_FAILED)
                 KAlarm::outputAlarmWarnings(dlg);
+            }
         }
     }
 }
@@ -1186,9 +1197,7 @@ void MainWindow::executeDragEnterEvent(QDragEnterEvent* e)
 {
     const QMimeData* data = e->mimeData();
     bool accept = ICalDrag::canDecode(data) ? !e->source()   // don't accept "text/calendar" objects from this application
-                                               :    data->hasText()
-                                                 || data->hasUrls()
-                                                 || KPIM::MailList::canDecode(data);
+                                            : data->hasText() || data->hasUrls();
     if (accept)
         e->acceptProposedAction();
 }
@@ -1202,12 +1211,6 @@ void MainWindow::dropEvent(QDropEvent* e)
     executeDropEvent(this, e);
 }
 
-static QString getMailHeader(const char* header, KMime::Content& content)
-{
-    KMime::Headers::Base* hd = content.headerByType(header);
-    return hd ? hd->asUnicodeString() : QString();
-}
-
 /******************************************************************************
 * Called when an object is dropped on a main or system tray window, to
 * evaluate the action required and extract the text.
@@ -1217,9 +1220,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Formats:" << e->mimeData()->formats();
     const QMimeData* data = e->mimeData();
     KAEvent::SubAction action = KAEvent::MESSAGE;
-    QByteArray         bytes;
     AlarmText          alarmText;
-    KPIM::MailList     mailList;
     QList<QUrl>        urls;
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeSpecAsZone()));
 #ifndef NDEBUG
@@ -1231,46 +1232,11 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
      * provide more than one mime type.
      * Don't change them without careful thought !!
      */
-    if (!(bytes = data->data(QStringLiteral("message/rfc822"))).isEmpty())
+    if (DragDrop::dropRFC822(data, alarmText))
     {
         // Email message(s). Ignore all but the first.
         qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: email";
-        KMime::Content content;
-        content.setContent(bytes);
-        content.parse();
-        QString body;
-        if (content.textContent())
-            body = content.textContent()->decodedText(true, true);    // strip trailing newlines & spaces
-        unsigned long sernum = 0;
-        if (KPIM::MailList::canDecode(data))
-        {
-            // Get its KMail serial number to allow the KMail message
-            // to be called up from the alarm message window.
-            mailList = KPIM::MailList::fromMimeData(data);
-            if (!mailList.isEmpty())
-                sernum = mailList.at(0).serialNumber();
-        }
-        alarmText.setEmail(getMailHeader("To", content),
-                           getMailHeader("From", content),
-                           getMailHeader("Cc", content),
-                           getMailHeader("Date", content),
-                           getMailHeader("Subject", content),
-                   body, sernum);
-    }
-    else if (KPIM::MailList::canDecode(data))
-    {
-        mailList = KPIM::MailList::fromMimeData(data);
-        // KMail message(s). Ignore all but the first.
-        qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: KMail_list";
-        if (mailList.isEmpty())
-            return;
-        const KPIM::MailSummary& summary = mailList.at(0);
-        QDateTime dt;
-        dt.setSecsSinceEpoch(summary.date());
-        const QString body = KAMail::getMailBody(summary.serialNumber());
-        alarmText.setEmail(summary.to(), summary.from(), QString(),
-                           QLocale().toString(dt), summary.subject(),
-                           body, summary.serialNumber());
+//TODO: Fetch attachments if an email alarm is created below
     }
     else if (ICalDrag::fromMimeData(data, calendar))
     {
@@ -1345,48 +1311,19 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
         }
         return;
     }
-    else if (!(urls = data->urls()).isEmpty())
+    else
     {
-        const QUrl& url(urls.at(0));
-        const Akonadi::Item item = Akonadi::Item::fromUrl(url);
-        if (item.isValid())
+        QUrl url;
+        Akonadi::Item item;
+        if (DragDrop::dropAkonadiEmail(data, url, item, alarmText))
         {
-            // It's an Akonadi item
-            qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi item" << item.id();
-            if (QUrlQuery(url).queryItemValue(QStringLiteral("type")) == QLatin1String("message/rfc822"))
-            {
-                // It's an email held in Akonadi
-                qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi email";
-                Akonadi::ItemFetchJob* job = new Akonadi::ItemFetchJob(item);
-                job->fetchScope().fetchFullPayload();
-                Akonadi::Item::List items;
-                if (job->exec())
-                    items = job->items();
-                if (items.isEmpty())
-                {
-                    qCWarning(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi item" << item.id() << "not found";
-                    return;
-                }
-                const Akonadi::Item& it = items.at(0);
-                if (!it.isValid()  ||  !it.hasPayload<KMime::Message::Ptr>())
-                {
-                    qCWarning(KALARM_LOG) << "MainWindow::executeDropEvent: invalid email";
-                    return;
-                }
-                KMime::Message::Ptr message = it.payload<KMime::Message::Ptr>();
-                QString body;
-                if (message->textContent())
-                    body = message->textContent()->decodedText(true, true);    // strip trailing newlines & spaces
-                alarmText.setEmail(getMailHeader("To", *message),
-                                   getMailHeader("From", *message),
-                                   getMailHeader("Cc", *message),
-                                   getMailHeader("Date", *message),
-                                   getMailHeader("Subject", *message),
-                           body, it.id());
-            }
+            // It's an email held in Akonadi
+            qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi email";
+//TODO: Fetch attachments if an email alarm is created below
         }
-        else
+        else if (!url.isEmpty()  &&  !item.isValid())
         {
+            // The data provides a URL, but it isn't an Akonadi URL.
             qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: URL";
             // Try to find the mime type of the file, without downloading a remote file
             QMimeDatabase mimeDb;
@@ -1421,8 +1358,8 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             else if (alarmText.isScript())
                 types += i18nc("@item:inlistbox", "Command Alarm");
             bool ok = false;
-            QString type = QInputDialog::getItem(mainMainWindow(), i18nc("@title:window", "Alarm Type"),
-                                                 i18nc("@info", "Choose alarm type to create:"), types, 0, false, &ok);
+            const QString type = QInputDialog::getItem(mainMainWindow(), i18nc("@title:window", "Alarm Type"),
+                                                       i18nc("@info", "Choose alarm type to create:"), types, 0, false, &ok);
             if (!ok)
                 return;   // user didn't press OK
             int i = types.indexOf(type);
@@ -1478,7 +1415,7 @@ void MainWindow::slotSelection()
     bool enableEnableDisable = true;
     bool enableEnable = false;
     bool enableDisable = false;
-    AlarmCalendar* resources = AlarmCalendar::resources();
+    ResourcesCalendar* resources = ResourcesCalendar::instance();
     const KADateTime now = KADateTime::currentUtcDateTime();
     for (int i = 0;  i < count;  ++i)
     {
