@@ -21,15 +21,15 @@
 #include "messagewin.h"
 #include "messagewin_p.h"
 #include "config-kalarm.h"
-#include <kio_version.h>
 
-#include "alarmcalendar.h"
 #include "deferdlg.h"
+#include "displaycalendar.h"
 #include "editdlg.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "mainwindow.h"
 #include "preferences.h"
+#include "resourcescalendar.h"
 #include "resources/resources.h"
 #include "lib/autoqpointer.h"
 #include "lib/config.h"
@@ -45,6 +45,7 @@
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
 
+#include <kwindowsystem_version.h>
 #include <KAboutData>
 #include <KStandardGuiItem>
 #include <KLocalizedString>
@@ -74,7 +75,6 @@
 #include <QLabel>
 #include <QPalette>
 #include <QTimer>
-#include <QPixmap>
 #include <QByteArray>
 #include <QFrame>
 #include <QGridLayout>
@@ -219,7 +219,7 @@ MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
         mDateTime = alarm.dateTime(true);
     if (!(flags & (NO_INIT_VIEW | ALWAYS_HIDE)))
     {
-        const bool readonly = AlarmCalendar::resources()->eventReadOnly(mEventId.eventId());
+        const bool readonly = ResourcesCalendar::instance()->eventReadOnly(mEventId.eventId());
         mShowEdit = !mEventId.isEmpty()  &&  !readonly;
         mNoDefer  = readonly || (flags & NO_DEFER) || alarm.repeatAtLogin();
         initView();
@@ -343,9 +343,10 @@ void MessageWin::initView()
     QWidget* topWidget = new QWidget(this);
     setCentralWidget(topWidget);
     QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
-    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    topLayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    const int dcmLeft   = style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
+    const int dcmTop    = style()->pixelMetric(QStyle::PM_LayoutTopMargin);
+    const int dcmRight  = style()->pixelMetric(QStyle::PM_LayoutRightMargin);
+    const int dcmBottom = style()->pixelMetric(QStyle::PM_LayoutBottomMargin);
 
     QPalette labelPalette = palette();
     labelPalette.setColor(backgroundRole(), labelPalette.color(QPalette::Window));
@@ -398,11 +399,7 @@ void MessageWin::initView()
                 // Display contents of file
                 const QUrl url = QUrl::fromUserInput(mMessage, QString(), QUrl::AssumeLocalFile);
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-                auto statJob = KIO::stat(url, KIO::StatJob::SourceSide, 0, KIO::HideProgressInfo);
-#else
                 auto statJob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatBasic, KIO::HideProgressInfo);
-#endif
                 const bool exists = statJob->exec();
                 const bool isDir = statJob->statResult().isDir();
 
@@ -495,7 +492,7 @@ void MessageWin::initView()
                 text->setMaximumWidth(s.width() + text->scrollBarWidth());
                 text->setWhatsThis(i18nc("@info:whatsthis", "The alarm message"));
                 const int vspace = lineSpacing/2;
-                const int hspace = lineSpacing - style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+                const int hspace = lineSpacing - (dcmLeft + dcmRight)/2;
                 topLayout->addSpacing(vspace);
                 topLayout->addStretch();
                 // Don't include any horizontal margins if message is 2/3 screen width
@@ -548,7 +545,7 @@ void MessageWin::initView()
                 MinuteTimer::connect(this, SLOT(setRemainingTextMinute()));   // update every minute
             }
             topLayout->addWidget(mRemainingText, 0, Qt::AlignHCenter);
-            topLayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+            topLayout->addSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
             topLayout->addStretch();
         }
     }
@@ -565,8 +562,6 @@ void MessageWin::initView()
                 frame->setWhatsThis(i18nc("@info:whatsthis", "The email to send"));
                 topLayout->addWidget(frame, 0, Qt::AlignHCenter);
                 QGridLayout* grid = new QGridLayout(frame);
-                grid->setContentsMargins(dcm, dcm, dcm, dcm);
-                grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
                 QLabel* label = new QLabel(i18nc("@info Email addressee", "To:"), frame);
                 label->setFixedSize(label->sizeHint());
@@ -592,7 +587,7 @@ void MessageWin::initView()
         }
     }
 
-    if (!mErrorMsgs.count())
+    if (mErrorMsgs.isEmpty())
     {
         topWidget->setAutoFillBackground(true);
         QPalette palette = topWidget->palette();
@@ -603,8 +598,7 @@ void MessageWin::initView()
     {
         setCaption(i18nc("@title:window", "Error"));
         QHBoxLayout* layout = new QHBoxLayout();
-        int m = 2 * dcm;
-        layout->setContentsMargins(m, m, m, m);
+        layout->setContentsMargins(2 * dcmLeft, 2 * dcmTop, 2 * dcmRight, 2 * dcmBottom);
         layout->addStretch();
         topLayout->addLayout(layout);
         QLabel* label = new QLabel(topWidget);
@@ -722,7 +716,7 @@ void MessageWin::initView()
     mKAlarmButton->setEnabled(false);
 
     topLayout->activate();
-    setMinimumSize(QSize(grid->sizeHint().width() + 2 * style()->pixelMetric(QStyle::PM_DefaultChildMargin),
+    setMinimumSize(QSize(grid->sizeHint().width() + dcmLeft + dcmRight,
                          sizeHint().height()));
     const bool modal = !(windowFlags() & Qt::X11BypassWindowManagerHint);
     NET::States wstate = NET::Sticky | NET::KeepAbove;
@@ -984,8 +978,8 @@ void MessageWin::saveProperties(KConfigGroup& config)
 void MessageWin::readProperties(const KConfigGroup& config)
 {
     mInvalid             = config.readEntry("Invalid", false);
-    const QString eventId         = config.readEntry("EventID");
-    const ResourceId collectionId = config.readEntry("CollectionID", ResourceId(-1));
+    const QString eventId       = config.readEntry("EventID");
+    const ResourceId resourceId = config.readEntry("CollectionID", ResourceId(-1));
     mAlarmType           = static_cast<KAAlarm::Type>(config.readEntry("AlarmType", 0));
     if (mAlarmType == KAAlarm::INVALID_ALARM)
     {
@@ -1033,8 +1027,8 @@ void MessageWin::readProperties(const KConfigGroup& config)
     mDontShowAgain       = config.readEntry("DontShowAgain", QString());
     mShowEdit            = false;
     // Temporarily initialise mResource and mEventId - they will be set by redisplayAlarm()
-    mResource            = Resources::resource(collectionId);
-    mEventId             = EventId(collectionId, eventId);
+    mResource            = Resources::resource(resourceId);
+    mEventId             = EventId(resourceId, eventId);
     qCDebug(KALARM_LOG) << "MessageWin::readProperties:" << eventId;
     if (mAlarmType != KAAlarm::INVALID_ALARM)
     {
@@ -1079,7 +1073,7 @@ void MessageWin::redisplayAlarm()
         qCDebug(KALARM_LOG) << "MessageWin::redisplayAlarm: Deleting duplicate window:" << mEventId;
     delete duplicate;
 
-    KAEvent* event = AlarmCalendar::resources()->event(mEventId);
+    KAEvent* event = ResourcesCalendar::instance()->event(mEventId);
     if (event)
     {
         mEvent = *event;
@@ -1106,7 +1100,7 @@ void MessageWin::redisplayAlarms()
         return;
     qCDebug(KALARM_LOG) << "MessageWin::redisplayAlarms";
     mRedisplayed = true;
-    AlarmCalendar* cal = AlarmCalendar::displayCalendar();
+    DisplayCalendar* cal = DisplayCalendar::instance();
     if (cal  &&  cal->isOpen())
     {
         KAEvent event;
@@ -1145,11 +1139,12 @@ void MessageWin::redisplayAlarms()
 
 /******************************************************************************
 * Retrieves the event with the current ID from the displaying calendar file,
-* or if not found there, from the archive calendar.
+* or if not found there, from the archive calendar. 'resource' is set to the
+* resource which originally contained the event, or invalid if not known.
 */
 bool MessageWin::retrieveEvent(KAEvent& event, Resource& resource, bool& showEdit, bool& showDefer)
 {
-    const Event::Ptr kcalEvent = AlarmCalendar::displayCalendar()->kcalEvent(CalEvent::uid(mEventId.eventId(), CalEvent::DISPLAYING));
+    const Event::Ptr kcalEvent = DisplayCalendar::instance()->kcalEvent(CalEvent::uid(mEventId.eventId(), CalEvent::DISPLAYING));
     if (!reinstateFromDisplaying(kcalEvent, event, resource, showEdit, showDefer))
     {
         // The event isn't in the displaying calendar.
@@ -1157,7 +1152,7 @@ bool MessageWin::retrieveEvent(KAEvent& event, Resource& resource, bool& showEdi
         KAEvent* ev = nullptr;
         Resource archiveRes = Resources::getStandard(CalEvent::ARCHIVED);
         if (archiveRes.isValid())
-            ev = AlarmCalendar::resources()->event(EventId(archiveRes.id(), CalEvent::uid(mEventId.eventId(), CalEvent::ARCHIVED)));
+            ev = ResourcesCalendar::instance()->event(EventId(archiveRes.id(), CalEvent::uid(mEventId.eventId(), CalEvent::ARCHIVED)));
         if (!ev)
             return false;
         event = *ev;
@@ -1176,7 +1171,8 @@ bool MessageWin::retrieveEvent(KAEvent& event, Resource& resource, bool& showEdi
 
 /******************************************************************************
 * Retrieves the displayed event from the calendar file, or if not found there,
-* from the displaying calendar.
+* from the displaying calendar. 'resource' is set to the resource which
+* originally contained the event.
 */
 bool MessageWin::reinstateFromDisplaying(const Event::Ptr& kcalEvent, KAEvent& event, Resource& resource, bool& showEdit, bool& showDefer)
 {
@@ -1184,7 +1180,7 @@ bool MessageWin::reinstateFromDisplaying(const Event::Ptr& kcalEvent, KAEvent& e
         return false;
     ResourceId resourceId;
     event.reinstateFromDisplaying(kcalEvent, resourceId, showEdit, showDefer);
-    event.setCollectionId(resourceId);
+    event.setResourceId(resourceId);
     resource = Resources::resource(resourceId);
     qCDebug(KALARM_LOG) << "MessageWin::reinstateFromDisplaying:" << EventId(event) << ": success";
     return true;
@@ -1211,10 +1207,10 @@ void MessageWin::alarmShowing(KAEvent& event)
         const ResourceId id = Resources::resourceForEvent(event.id()).id();
         dispEvent.setDisplaying(event, mAlarmType, id,
                                 mDateTime.effectiveKDateTime(), mShowEdit, !mNoDefer);
-        AlarmCalendar* cal = AlarmCalendar::displayCalendarOpen();
+        DisplayCalendar* cal = DisplayCalendar::instanceOpen();
         if (cal)
         {
-            cal->deleteDisplayEvent(dispEvent.id());   // in case it already exists
+            cal->deleteEvent(dispEvent.id());   // in case it already exists
             cal->addEvent(dispEvent);
             cal->save();
         }
@@ -1659,7 +1655,7 @@ void MessageWin::repeat(const KAAlarm& alarm)
         delete mDeferDlg;
         mDeferDlg = nullptr;
     }
-    KAEvent* event = mEventId.isEmpty() ? nullptr : AlarmCalendar::resources()->event(mEventId);
+    KAEvent* event = mEventId.isEmpty() ? nullptr : ResourcesCalendar::instance()->event(mEventId);
     if (event)
     {
         mAlarmType = alarm.type();    // store new alarm type for use if it is later deferred
@@ -1721,7 +1717,8 @@ QSize MessageWin::sizeHint() const
             {
                 // For command output, expand the window to accommodate the text
                 const QSize texthint = mCommandText->sizeHint();
-                int w = texthint.width() + 2 * style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+                int w = texthint.width() + style()->pixelMetric(QStyle::PM_LayoutLeftMargin)
+                                         + style()->pixelMetric(QStyle::PM_LayoutRightMargin);
                 if (w < width())
                     w = width();
                 const int ypadding = height() - mCommandText->height();
@@ -2153,7 +2150,7 @@ void MessageWin::slotDefer()
         const int      delayMins = mDeferDlg->deferMinutes();
         // Fetch the up-to-date alarm from the calendar. Note that it could have
         // changed since it was displayed.
-        const KAEvent* event = mEventId.isEmpty() ? nullptr : AlarmCalendar::resources()->event(mEventId);
+        const KAEvent* event = mEventId.isEmpty() ? nullptr : ResourcesCalendar::instance()->event(mEventId);
         if (event)
         {
             // The event still exists in the active calendar
@@ -2168,7 +2165,7 @@ void MessageWin::slotDefer()
         else
         {
             // Try to retrieve the event from the displaying or archive calendars
-            Resource resource;
+            Resource resource;   // receives the event's original resource, if known
             KAEvent event;
             bool showEdit, showDefer;
             if (!retrieveEvent(event, resource, showEdit, showDefer))
@@ -2189,13 +2186,14 @@ void MessageWin::slotDefer()
             event.setCommandError(mCommandError);
             // Add the event back into the calendar file, retaining its ID
             // and not updating KOrganizer.
-            KAlarm::addEvent(event, &resource, mDeferDlg, KAlarm::USE_EVENT_ID);
+            KAlarm::addEvent(event, resource, mDeferDlg, KAlarm::USE_EVENT_ID);
             if (event.deferred())
                 mNoPostAction = true;
             // Finally delete it from the archived calendar now that it has
             // been reactivated.
             event.setCategory(CalEvent::ARCHIVED);
-            KAlarm::deleteEvent(event, false);
+            Resource res;
+            KAlarm::deleteEvent(event, res, false);
         }
         if (theApp()->wantShowInSystemTray())
         {
