@@ -1,7 +1,7 @@
 /*
  *  recurrenceedit.cpp  -  widget to edit the event's recurrence definition
  *  Program:  kalarm
- *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2020 David Jarvie <djarvie@kde.org>
  *
  *  Based originally on KOrganizer module koeditorrecurrence.cpp,
  *  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
@@ -45,7 +45,6 @@
 using namespace KCalendarCore;
 
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <KDateComboBox>
 
 #include <QHBoxLayout>
@@ -85,7 +84,6 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     qCDebug(KALARM_LOG) << "RecurrenceEdit:";
     QVBoxLayout* topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
-    topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     /* Create the recurrence rule Group box which holds the recurrence period
      * selection buttons, and the weekly, monthly and yearly recurrence rule
@@ -97,9 +95,9 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     QGroupBox* recurGroup = new QGroupBox(i18nc("@title:group", "Recurrence Rule"), this);
     topLayout->addWidget(recurGroup);
     QHBoxLayout* hlayout = new QHBoxLayout(recurGroup);
-    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    hlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    hlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultChildMargin));   // use margin spacing due to vertical divider line
+    const int marLeft  = style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
+    const int marRight = style()->pixelMetric(QStyle::PM_LayoutRightMargin);
+    hlayout->setSpacing((marLeft + marRight)/2);   // use margin spacing due to vertical divider line
 
     // Recurrence period radio buttons
     QVBoxLayout* vlayout = new QVBoxLayout();
@@ -171,7 +169,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     connect(mSubRepetition, &RepetitionButton::needsInitialisation, this, &RecurrenceEdit::repeatNeedsInitialisation);
     connect(mSubRepetition, &RepetitionButton::changed, this, &RecurrenceEdit::frequencyChanged);
     connect(mSubRepetition, &RepetitionButton::changed, this, &RecurrenceEdit::contentsChanged);
-    vlayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    vlayout->addSpacing(style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
     vlayout->addWidget(mSubRepetition);
 
     // Vertical divider line
@@ -210,7 +208,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRuleStack->addWidget(mWeeklyRule);
     mRuleStack->addWidget(mMonthlyRule);
     mRuleStack->addWidget(mYearlyRule);
-    hlayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+    hlayout->addSpacing((marLeft + marRight)/2);
 
     // Create the recurrence range group which contains the controls
     // which specify how long the recurrence is to last.
@@ -222,8 +220,6 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     connect(mRangeButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::contentsChanged);
 
     vlayout = new QVBoxLayout(mRangeButtonBox);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mNoEndDateButton = new RadioButton(i18nc("@option:radio", "No end"), mRangeButtonBox);
     mNoEndDateButton->setFixedSize(mNoEndDateButton->sizeHint());
     mNoEndDateButton->setReadOnly(mReadOnly);
@@ -251,7 +247,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRepeatCountLabel = new QLabel(i18nc("@label", "occurrence(s)"), mRangeButtonBox);
     mRepeatCountLabel->setFixedSize(mRepeatCountLabel->sizeHint());
     hlayout->addWidget(mRepeatCountButton);
-    hlayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->addSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     hlayout->addWidget(mRepeatCountEntry);
     hlayout->addWidget(mRepeatCountLabel);
     hlayout->addStretch();
@@ -286,7 +282,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     connect(mEndAnyTimeCheckBox, &CheckBox::toggled, this, &RecurrenceEdit::slotAnyTimeToggled);
     connect(mEndAnyTimeCheckBox, &CheckBox::toggled, this, &RecurrenceEdit::contentsChanged);
     hlayout->addWidget(mEndDateButton);
-    hlayout->addSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->addSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     hlayout->addWidget(mEndDateEdit);
     hlayout->addWidget(mEndTimeEdit);
     hlayout->addWidget(mEndAnyTimeCheckBox);
@@ -304,8 +300,6 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     topLayout->addWidget(mExceptionGroup);
     topLayout->setStretchFactor(mExceptionGroup, 2);
     hlayout = new QHBoxLayout(mExceptionGroup);
-    hlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    hlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     vlayout = new QVBoxLayout();
     vlayout->setContentsMargins(0, 0, 0, 0);
     hlayout->addLayout(vlayout);
@@ -1085,11 +1079,9 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
 {
     mLayout = new QVBoxLayout(this);
     mLayout->setContentsMargins(0, 0, 0, 0);
-    mLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     QHBoxLayout* freqLayout = new QHBoxLayout();
     freqLayout->setContentsMargins(0, 0, 0, 0);
-    freqLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mLayout->addLayout(freqLayout);
     QWidget* box = new QWidget(this);    // this is to control the QWhatsThis text display area
     freqLayout->addWidget(box, 0, Qt::AlignLeft);
@@ -1189,14 +1181,13 @@ DayWeekRule::DayWeekRule(const QString& freqText, const QString& freqWhatsThis,
     QLabel* label = new QLabel(i18nc("@label On: Tuesday", "O&n:"), this);
     label->setFixedSize(label->sizeHint());
     grid->addWidget(label, 0, 0, Qt::AlignRight | Qt::AlignTop);
-    grid->setColumnMinimumWidth(1, style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    grid->setColumnMinimumWidth(1, style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
 
     // List the days of the week starting at the user's start day of the week.
     // Save the first day of the week, just in case it changes while the dialog is open.
     QWidget* box = new QWidget(this);   // this is to control the QWhatsThis text display area
     QGridLayout* dgrid = new QGridLayout(box);
     dgrid->setContentsMargins(0, 0, 0, 0);
-    dgrid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLocale locale;
     for (int i = 0;  i < 7;  ++i)
     {
@@ -1336,7 +1327,6 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     // Month day selector
     QGridLayout* boxLayout = new QGridLayout();
     boxLayout->setContentsMargins(0, 0, 0, 0);
-    boxLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     layout()->addLayout(boxLayout);
 
     mDayButton = new RadioButton(i18nc("@option:radio On day number in the month", "O&n day"), this);
@@ -1552,7 +1542,6 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     hlayout->addWidget(w, 1, Qt::AlignLeft);
     QGridLayout* grid = new QGridLayout(w);
     grid->setContentsMargins(0, 0, 0, 0);
-    grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLocale locale;
     for (int i = 0;  i < 12;  ++i)
     {
@@ -1573,7 +1562,6 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     f29box->addWidget(w, 0, Qt::AlignLeft);
     QHBoxLayout* boxLayout = new QHBoxLayout(w);
     boxLayout->setContentsMargins(0, 0, 0, 0);
-    boxLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mFeb29Label = new QLabel(i18nc("@label:listbox", "February 2&9th alarm in non-leap years:"));
     mFeb29Label->setFixedSize(mFeb29Label->sizeHint());
     boxLayout->addWidget(mFeb29Label);
