@@ -24,12 +24,15 @@
 #include "resourcedatamodelbase.h"
 #include "resourcemodel.h"
 #include "resourceselectdialog.h"
+
 #include "preferences.h"
 #include "lib/autoqpointer.h"
+#include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
 
+
 Resources* Resources::mInstance {nullptr};
 
 // Copy of all ResourceType instances with valid ID, wrapped in the Resource
@@ -373,6 +376,7 @@ void Resources::notifyNewResourceInitialised(Resource& res)
 */
 void Resources::notifyResourcesCreated()
 {
+    qCDebug(KALARM_LOG) << "Resources::notifyResourcesCreated";
     mCreated = true;
     Q_EMIT instance()->resourcesCreated();
     checkResourcesPopulated();
@@ -395,14 +399,6 @@ void Resources::notifyResourcePopulated(const ResourceType* res)
     checkResourcesPopulated();
 }
 
-/******************************************************************************
-* Called to notify that migration/creation of resources has completed.
-*/
-void Resources::notifyResourcesMigrated()
-{
-    Q_EMIT instance()->migrationCompleted();
-}
-
 /******************************************************************************
 * Called to notify that a resource is about to be removed.
 */
@@ -482,25 +478,25 @@ void Resources::notifySettingsChanged(ResourceType* res, ResourceType::Changes c
             switch (std)
             {
                 case CalEvent::ACTIVE:
-                    msg = xi18n("The calendar <resource>%1</resource> has been made read-only. "
-                            "This was the default calendar for active alarms.",
-                            res->displayName());
+                    msg = xi18nc("@info", "The calendar <resource>%1</resource> has been made read-only. "
+                                 "This was the default calendar for active alarms.",
+                                 res->displayName());
                     break;
                 case CalEvent::ARCHIVED:
-                    msg = xi18n("The calendar <resource>%1</resource> has been made read-only. "
-                            "This was the default calendar for archived alarms.",
-                            res->displayName());
+                    msg = xi18nc("@info", "The calendar <resource>%1</resource> has been made read-only. "
+                                 "This was the default calendar for archived alarms.",
+                                 res->displayName());
                     break;
                 case CalEvent::TEMPLATE:
-                    msg = xi18n("The calendar <resource>%1</resource> has been made read-only. "
-                            "This was the default calendar for alarm templates.",
-                            res->displayName());
+                    msg = xi18nc("@info", "The calendar <resource>%1</resource> has been made read-only. "
+                                 "This was the default calendar for alarm templates.",
+                                 res->displayName());
                     break;
                 default:
                     msg = xi18nc("@info", "<para>The calendar <resource>%1</resource> has been made read-only. "
-                            "This was the default calendar for:%2</para>"
-                            "<para>Please select new default calendars.</para>",
-                            res->displayName(), ResourceDataModelBase::typeListForDisplay(std));
+                                 "This was the default calendar for:%2</para>"
+                                 "<para>Please select new default calendars.</para>",
+                                 res->displayName(), ResourceDataModelBase::typeListForDisplay(std));
                     singleType = false;
                     break;
             }
