@@ -26,7 +26,6 @@
 #include "resourcemodel.h"
 
 #include <QObject>
-class QEventLoop;
 
 using namespace KAlarmCal;
 
@@ -54,12 +53,21 @@ public:
      */
     static bool removeResource(Resource&);
 
+    /** Sorting criteria for allResources(Type, Sorting). May be OR'ed together. */
+    enum Sorts
+    {
+        NoSort       = 0,
+        DisplayName  = 0x01,   // sort by display name
+        DefaultFirst = 0x02    // default resource is first in list. Requires a CalEvent::Type to be specified.
+    };
+    Q_DECLARE_FLAGS(Sorting, Sorts)
     /** Return all resources of a kind which contain a specified alarm type.
-     *  @tparam Type       Resource type to fetch, default = all types.
+     *  @tparam RType      Resource type to fetch, default = all types.
      *  @param  alarmType  Alarm type to check for, or CalEvent::EMPTY for any type.
+     *  @param  sorting    Sorting criteria to use.
      */
-    template <class Type = ResourceType>
-    static QVector<Resource> allResources(CalEvent::Type alarmType = CalEvent::EMPTY);
+    template <class RType = ResourceType>
+    static QVector<Resource> allResources(CalEvent::Type alarmType = CalEvent::EMPTY, Sorting sorting = NoSort);
 
     /** Return the enabled resources which contain a specified alarm type.
      *  @param type      Alarm type to check for, or CalEvent::EMPTY for any type.
@@ -124,10 +132,11 @@ public:
      */
     static Resource destination(CalEvent::Type type, QWidget* promptParent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
 
-    /** Return whether all configured resources have been created. */
+    /** Return whether all configured and migrated resources have been created. */
     static bool allCreated();
 
-    /** Return whether all configured resources have been loaded at least once. */
+    /** Return whether all configured and migrated resources have been loaded
+     *  at least once. */
     static bool allPopulated();
 
     /** Return the resource which an event belongs to, provided that the event's
@@ -145,15 +154,13 @@ public:
      *  in order to emit the resourceAdded() signal. */
     static void notifyNewResourceInitialised(Resource&);
 
-    /** Called to notify that all configured resources have now been created. */
+    /** Called to notify that all configured and migrated resources have now
+     *  been created. */
     static void notifyResourcesCreated();
 
     /** Called by a resource to notify that loading of events has successfully completed. */
     static void notifyResourcePopulated(const ResourceType*);
 
-    /** Called to notify that migration/creation of resources has completed. */
-    static void notifyResourcesMigrated();
-
     /** Called to notify that a resource is about to be removed. */
     static void notifyResourceToBeRemoved(ResourceType*);
 
@@ -195,18 +202,16 @@ Q_SIGNALS:
     void settingsChanged(Resource&, ResourceType::Changes);
 
     /** Emitted when all configured resource have been created (but not
-     *  necessarily populated). Note that after this, resource migration and
-     *  the creation of default resources is performed and notified by the
-     *  signal migrationCompleted().
+     *  necessarily populated), and any necessary resource migration and
+     *  the creation of default resources has been performed.
      */
     void resourcesCreated();
 
-    /** Emitted when all configured resources have been loaded for the first time. */
+    /** Emitted when all configured and migrated resources have been loaded for
+     *  the first time.
+     */
     void resourcesPopulated();
 
-    /** Signal emitted when resource migration/creation at startup has completed. */
-    void migrationCompleted();
-
     /** Emitted when a new resource has been created. */
     void resourceAdded(Resource&);
 
@@ -278,25 +283,40 @@ private:
     friend class ResourceType;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Resources::Sorting)
+
 
 /*=============================================================================
 * Template definitions.
 *============================================================================*/
 
-template <class Type>
-QVector<Resource> Resources::allResources(CalEvent::Type type)
+template <class RType>
+QVector<Resource> Resources::allResources(CalEvent::Type type, Sorting sorting)
 {
     const CalEvent::Types types = (type == CalEvent::EMPTY)
                                 ? CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE
                                 : type;
 
     QVector<Resource> result;
+    Resource std;
+    if ((sorting & DefaultFirst)  &&  type != CalEvent::EMPTY)
+    {
+        std = getStandard(type);
+        if (std.isValid()  &&  std.is<RType>())
+            result += std;
+    }
+    const int start = result.size();
+
     for (auto it = mResources.constBegin();  it != mResources.constEnd();  ++it)
     {
         const Resource& res = it.value();
-        if (res.is<Type>()  &&  (res.alarmTypes() & types))
+        if (res != std  &&  res.is<RType>()  &&  (res.alarmTypes() & types))
             result += res;
     }
+
+    if (sorting & DisplayName)
+        std::sort(result.begin() + start, result.end(), [](const Resource& a, const Resource& b) { return a.displayName().compare(b.displayName(), Qt::CaseInsensitive) < 0; });
+
     return result;
 }
 
