@@ -24,9 +24,10 @@
 
 #include "resourceselector.h"
 
-#include "alarmcalendar.h"
+#include "functions.h"
 #include "kalarmapp.h"
 #include "preferences.h"
+#include "resourcescalendar.h"
 #include "resources/akonadidatamodel.h"
 #include "resources/akonadiresourcecreator.h"
 #include "resources/akonadiresourcemigrator.h"
@@ -454,7 +455,7 @@ void ResourceSelector::setStandard()
 void ResourceSelector::importCalendar()
 {
     Resource resource = currentResource();
-    AlarmCalendar::resources()->importAlarms(this, &resource);
+    KAlarm::importAlarms(resource, this);
 }
 
 /******************************************************************************
@@ -465,7 +466,7 @@ void ResourceSelector::exportCalendar()
 {
     const Resource resource = currentResource();
     if (resource.isValid())
-        AlarmCalendar::exportAlarms(AlarmCalendar::resources()->events(resource), this);
+        KAlarm::exportAlarms(ResourcesCalendar::instance()->events(resource), this);
 }
 
 /******************************************************************************
